Documentation
¶
Index ¶
- Variables
- func Debug(msg string, fields ...zapcore.Field)
- func Error(msg string, err error)
- func Fatal(msg string, fields ...zapcore.Field)
- func Info(msg string, fields ...zapcore.Field)
- func LevelEncoder() zapcore.LevelEncoder
- func Log() *zap.Logger
- func Panic(msg string, fields ...zapcore.Field)
- func Warn(msg string, fields ...zapcore.Field)
Constants ¶
This section is empty.
Variables ¶
var ( Level = "debug" Prefix = "mobinio" Format = "console" Director = "" EncodeLevel = "uppercase" StacktraceKey = "trace" ShowLine = false LogInConsole = true RetentionDay = 30 SentryDns = "" )
Functions ¶
func Debug ¶
Debug starts a new message with debug level.
You must call Msg on the returned event in order to send the event.
func Error ¶
Error starts a new message with error level.
You must call Msg on the returned event in order to send the event.
func Fatal ¶
Fatal starts a new message with fatal level. The os.Exit(1) function is called by the Msg method.
You must call Msg on the returned event in order to send the event.
func Info ¶
Info starts a new message with info level.
You must call Msg on the returned event in order to send the event.
func LevelEncoder ¶
func LevelEncoder() zapcore.LevelEncoder
func Log ¶
Log starts a new message with no level. Setting zerolog.GlobalLevel to zerolog.Disabled will still disable events produced by this method.
You must call Msg on the returned event in order to send the event.
Types ¶
This section is empty.